@@ -2,7 +2,7 @@
  * idctclassic.c : Classic IDCT module
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: idctclassic.c,v 1.21 2002/02/24 20:51:10 gbazin Exp $
+ * $Id: idctclassic.c,v 1.24 2002/05/18 17:47:46 sam Exp $
  *
  * Authors: Gal Hendryckx <jimmy@via.ecp.fr>
  *
@@ -44,7 +44,7 @@ MODULE_CONFIG_START
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    SET_DESCRIPTION( "classic IDCT module" )
+    SET_DESCRIPTION( _("classic IDCT module") )
     ADD_CAPABILITY( IDCT, 100 )
     ADD_SHORTCUT( "classic" )
     ADD_SHORTCUT( "idctclassic" )
@@ -69,7 +69,7 @@ static void NormScan( u8 ppi_scan[2][64] )
 /*****************************************************************************
  * IDCT : IDCT function for normal matrices
  *****************************************************************************/
-static __inline__ void IDCT( dctelem_t * p_block )
+static inline void IDCT( dctelem_t * p_block )
 {
     s32 tmp0, tmp1, tmp2, tmp3;
     s32 tmp10, tmp11, tmp12, tmp13;
@@ -287,6 +287,11 @@ static __inline__ void IDCT( dctelem_t * p_block )
     }
 }
 
+static inline void RestoreCPUState( )
+{
+    ;
+}
+
 #include "idct_sparse.h"
 #include "idct_decl.h"
 
