@@ -2,7 +2,7 @@
  * xmga.c : X11 MGA plugin for vlc
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: xmga.c,v 1.14 2002/05/18 17:47:47 sam Exp $
+ * $Id: xmga.c,v 1.15.2.1 2002/06/03 00:28:07 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -110,7 +110,7 @@ static void ToggleCursor   ( vout_thread_t * );
 MODULE_CONFIG_START
 ADD_CATEGORY_HINT( N_("Miscellaneous"), NULL )
 ADD_STRING  ( "xmga_display", NULL, NULL, DISPLAY_TEXT, DISPLAY_LONGTEXT )
-ADD_BOOL    ( "xmga_altfullscreen", NULL, ALT_FS_TEXT, ALT_FS_LONGTEXT )
+ADD_BOOL    ( "xmga_altfullscreen", 0, NULL, ALT_FS_TEXT, ALT_FS_LONGTEXT )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
@@ -555,6 +555,19 @@ static int vout_Manage( vout_thread_t *p_vout )
                                       INPUT_STATUS_PAUSE );
                      break;
 
+                 case XK_F1: network_ChannelJoin( 1 ); break;
+                 case XK_F2: network_ChannelJoin( 2 ); break;
+                 case XK_F3: network_ChannelJoin( 3 ); break;
+                 case XK_F4: network_ChannelJoin( 4 ); break;
+                 case XK_F5: network_ChannelJoin( 5 ); break;
+                 case XK_F6: network_ChannelJoin( 6 ); break;
+                 case XK_F7: network_ChannelJoin( 7 ); break;
+                 case XK_F8: network_ChannelJoin( 8 ); break;
+                 case XK_F9: network_ChannelJoin( 9 ); break;
+                 case XK_F10: network_ChannelJoin( 10 ); break;
+                 case XK_F11: network_ChannelJoin( 11 ); break;
+                 case XK_F12: network_ChannelJoin( 12 ); break;
+
                  default:
                      /* "Normal Keys"
                       * The reason why I use this instead of XK_0 is that 
@@ -575,17 +588,6 @@ static int vout_Manage( vout_thread_t *p_vout )
                             p_vout->i_changes |= VOUT_FULLSCREEN_CHANGE;
                             break;
 
-                        case '0': network_ChannelJoin( 0 ); break;
-                        case '1': network_ChannelJoin( 1 ); break;
-                        case '2': network_ChannelJoin( 2 ); break;
-                        case '3': network_ChannelJoin( 3 ); break;
-                        case '4': network_ChannelJoin( 4 ); break;
-                        case '5': network_ChannelJoin( 5 ); break;
-                        case '6': network_ChannelJoin( 6 ); break;
-                        case '7': network_ChannelJoin( 7 ); break;
-                        case '8': network_ChannelJoin( 8 ); break;
-                        case '9': network_ChannelJoin( 9 ); break;
-
                         default:
                             break;
                         }
