@@ -35,6 +35,7 @@
 
 //---------------------------------------------------------------------------
 //#pragma package(smart_init)
+#pragma link "CSPIN"
 #pragma resource "*.dfm"
 
 extern struct intf_thread_s *p_intfGlobal;
@@ -117,16 +118,20 @@ TEdit * __fastcall TGroupBoxPref::CreateEdit( TWinControl *Parent,
     return Edit;
 }
 //---------------------------------------------------------------------------
-TUpDown * __fastcall TGroupBoxPref::CreateUpDown( TWinControl *Parent,
-            int Min, int Max, int Position, bool Thousands )
+TCSpinEdit * __fastcall TGroupBoxPref::CreateSpinEdit( TWinControl *Parent,
+            int Left, int Width, int Top, int Height,
+            long Min, long Max, long Value )
 {
-    TUpDown *UpDown = new TUpDown( Parent );
-    UpDown->Parent = Parent;
-    UpDown->Min = Min;
-    UpDown->Max = Max;
-    UpDown->Position = Position;
-    UpDown->Thousands = Thousands;
-    return UpDown;
+    TCSpinEdit *SpinEdit = new TCSpinEdit( Parent );
+    SpinEdit->Parent = Parent;
+    SpinEdit->Left = Left;
+    SpinEdit->Width = Width;
+    SpinEdit->Top = Top;
+    SpinEdit->Height = Height;
+    SpinEdit->MinValue = Min;
+    SpinEdit->MaxValue = Max;
+    SpinEdit->Value = Value;
+    return SpinEdit;
 }
 //---------------------------------------------------------------------------
 void __fastcall TGroupBoxPref::UpdateChanges()
@@ -135,7 +140,7 @@ void __fastcall TGroupBoxPref::UpdateChanges()
 
 
 /****************************************************************************
- * GroupBox for plugin management
+ * GroupBox for module management
  ****************************************************************************/
 __fastcall TGroupBoxPlugin::TGroupBoxPlugin( TComponent* Owner,
             module_config_t *p_config ) : TGroupBoxPref( Owner, p_config )
@@ -185,7 +190,7 @@ void __fastcall TGroupBoxPlugin::ListViewSelectItem( TObject *Sender,
     Name = Item->Caption;
     if( Name != "" )
     {
-        /* look for plugin 'Name' */
+        /* look for module 'Name' */
         for( p_module = p_module_bank->first ;
              p_module != NULL ;
              p_module = p_module->next )
@@ -264,22 +269,20 @@ __fastcall TGroupBoxInteger::TGroupBoxInteger( TComponent* Owner,
     LabelDesc = CreateLabel( this, 230, 225, 19, 26,
                              p_config->psz_longtext, true );
 
-    /* init edit */
-    Edit = CreateEdit( this, 16, 148, 24, 21, "" );
-
-    /* init updown */
-    UpDown = CreateUpDown( this, -1, 32767, p_config->i_value, false );
-    UpDown->Associate = Edit;
+    /* init spinedit */
+    SpinEdit = CreateSpinEdit( this, 16, 164, 24, 21,
+                               -1, 100000, p_config->i_value );
 
     /* vertical alignment */
     Height = LabelDesc->Height + 24;
     LabelDesc->Top = Top + ( Height - LabelDesc->Height ) / 2 + 4;
-    Edit->Top = Top + ( Height - Edit->Height ) / 2 + 4;
+    SpinEdit->Top = Top + ( Height - SpinEdit->Height ) / 2 + 4;
 };
 //---------------------------------------------------------------------------
 void __fastcall TGroupBoxInteger::UpdateChanges()
 {
-    p_config->i_value = StrToInt( Edit->Text );
+    /* Warning: we're casting from long to int */
+    p_config->i_value = (int)SpinEdit->Value;
 }
 
 
@@ -357,9 +360,8 @@ void __fastcall TPreferencesDlg::FormHide( TObject *Sender )
 
 void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
 {
-    module_t           *p_module;
-    module_t           *p_module_plugins;
-    unsigned int        i;
+    module_t           *p_module, *p_module_plugins;
+    module_config_t    *p_item;
     int                 i_pages, i_ctrl;
     
     TTabSheet          *TabSheet;
@@ -385,16 +387,17 @@ void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
      */
 
     /* Enumerate config options and add corresponding config boxes */
-    for( i = 0; i < p_module->i_config_lines; i++ )
+    p_item = p_module->p_config;
+    do
     {
-        switch( p_module->p_config[i].i_type )
+        switch( p_item->i_type )
         {
         case MODULE_CONFIG_HINT_CATEGORY:
 
             /* create a new tabsheet. */
             TabSheet = new TTabSheet( this );
             TabSheet->PageControl = PageControlPref;
-            TabSheet->Caption = p_module->p_config[i].psz_text;
+            TabSheet->Caption = p_item->psz_text;
             TabSheet->Visible = true;
 
             /* pack a scrollbox into the tabsheet */
@@ -407,10 +410,10 @@ void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
 
             break;
 
-        case MODULE_CONFIG_ITEM_PLUGIN:
+        case MODULE_CONFIG_ITEM_MODULE:
 
             /* add new groupbox for the config option */
-            GroupBoxPlugin = new TGroupBoxPlugin( this, &p_module->p_config[i] );
+            GroupBoxPlugin = new TGroupBoxPlugin( this, p_item );
             GroupBoxPlugin->Parent = ScrollBox;
 
             /* add panel as separator */
@@ -422,7 +425,7 @@ void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
                  p_module_plugins = p_module_plugins->next )
             {
                 if( p_module_plugins->i_capabilities &
-                    ( 1 << p_module->p_config[i].i_value ) )
+                    ( 1 << p_item->i_value ) )
                 {
                     ListItem = GroupBoxPlugin->ListView->Items->Add();
                     ListItem->Caption = p_module_plugins->psz_name;
@@ -436,7 +439,7 @@ void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
         case MODULE_CONFIG_ITEM_STRING:
 
             /* add new groupbox for the config option */
-            GroupBoxString = new TGroupBoxString( this, &p_module->p_config[i] );
+            GroupBoxString = new TGroupBoxString( this, p_item );
             GroupBoxString->Parent = ScrollBox;
 
             /* add panel as separator */
@@ -447,7 +450,7 @@ void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
         case MODULE_CONFIG_ITEM_INTEGER:
 
             /* add new groupbox for the config option */
-            GroupBoxInteger = new TGroupBoxInteger( this, &p_module->p_config[i] );
+            GroupBoxInteger = new TGroupBoxInteger( this, p_item );
             GroupBoxInteger->Parent = ScrollBox;
 
             /* add panel as separator */
@@ -458,7 +461,7 @@ void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
         case MODULE_CONFIG_ITEM_BOOL:
 
             /* add new groupbox for the config option */
-            GroupBoxBool = new TGroupBoxBool( this, &p_module->p_config[i] );
+            GroupBoxBool = new TGroupBoxBool( this, p_item );
             GroupBoxBool->Parent = ScrollBox;
 
             /* add panel as separator */
@@ -466,7 +469,10 @@ void __fastcall TPreferencesDlg::CreateConfigDialog( char *psz_module_name )
 
             break;
         }
+        
+        p_item++;
     }
+    while( p_item->i_type != MODULE_CONFIG_HINT_END );
 
     /* Reorder groupboxes inside the tabsheets */
     for( i_pages = 0; i_pages < PageControlPref->PageCount; i_pages++ )
@@ -534,7 +540,7 @@ void __fastcall TPreferencesDlg::SaveValue( module_config_t *p_config )
     {
         case MODULE_CONFIG_ITEM_STRING:
         case MODULE_CONFIG_ITEM_FILE:
-        case MODULE_CONFIG_ITEM_PLUGIN:
+        case MODULE_CONFIG_ITEM_MODULE:
             config_PutPszVariable( p_config->psz_name,
                         *p_config->psz_value ? p_config->psz_value : NULL );
             break;
