@@ -2,7 +2,7 @@
  * xcommon.c: Functions common to the X11 and XVideo plugins
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: xcommon.c,v 1.34 2002/05/20 22:30:19 sam Exp $
+ * $Id: xcommon.c,v 1.35.2.1 2002/06/03 00:28:07 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -721,6 +721,19 @@ static int vout_Manage( vout_thread_t *p_vout )
                                       INPUT_STATUS_PAUSE );
                      break;
 
+                 case XK_F1: network_ChannelJoin( 1 ); break;
+                 case XK_F2: network_ChannelJoin( 2 ); break;
+                 case XK_F3: network_ChannelJoin( 3 ); break;
+                 case XK_F4: network_ChannelJoin( 4 ); break;
+                 case XK_F5: network_ChannelJoin( 5 ); break;
+                 case XK_F6: network_ChannelJoin( 6 ); break;
+                 case XK_F7: network_ChannelJoin( 7 ); break;
+                 case XK_F8: network_ChannelJoin( 8 ); break;
+                 case XK_F9: network_ChannelJoin( 9 ); break;
+                 case XK_F10: network_ChannelJoin( 10 ); break;
+                 case XK_F11: network_ChannelJoin( 11 ); break;
+                 case XK_F12: network_ChannelJoin( 12 ); break;
+
                  default:
                      /* "Normal Keys"
                       * The reason why I use this instead of XK_0 is that 
@@ -741,17 +754,6 @@ static int vout_Manage( vout_thread_t *p_vout )
                             p_vout->i_changes |= VOUT_FULLSCREEN_CHANGE;
                             break;
 
-                        case '0': network_ChannelJoin( 0 ); break;
-                        case '1': network_ChannelJoin( 1 ); break;
-                        case '2': network_ChannelJoin( 2 ); break;
-                        case '3': network_ChannelJoin( 3 ); break;
-                        case '4': network_ChannelJoin( 4 ); break;
-                        case '5': network_ChannelJoin( 5 ); break;
-                        case '6': network_ChannelJoin( 6 ); break;
-                        case '7': network_ChannelJoin( 7 ); break;
-                        case '8': network_ChannelJoin( 8 ); break;
-                        case '9': network_ChannelJoin( 9 ); break;
-
                         default:
                             break;
                         }
@@ -1540,13 +1542,20 @@ static void ToggleFullScreen ( vout_thread_t *p_vout )
                                  &attributes);
     }
 
-    /* We need to unmap and remap the window if we want the window 
-     * manager to take our changes into effect */
+    /* We need to reparent the window if we want the window 
+     * manager to take our changes into effect. We also resize the window
+     * twice to avoid an annoying flickering. */
+    if( !p_vout->b_fullscreen )
+        XMoveResizeWindow( p_vout->p_sys->p_display,
+                           p_vout->p_sys->window,
+                           i_xpos,
+                           i_ypos,
+                           i_width,
+                           i_height );
     XReparentWindow( p_vout->p_sys->p_display,
                      p_vout->p_sys->window,
                      DefaultRootWindow( p_vout->p_sys->p_display ),
                      0, 0 );
-    XSync( p_vout->p_sys->p_display, True );
     XMoveResizeWindow( p_vout->p_sys->p_display,
                        p_vout->p_sys->window,
                        i_xpos,
