@@ -4,7 +4,7 @@
  * and spawn threads.
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: main.c,v 1.195.2.2 2002/06/03 17:19:54 sam Exp $
+ * $Id: main.c,v 1.195.2.4 2002/07/19 21:14:40 massiot Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -217,6 +217,11 @@
 #define SERVER_PORT_LONGTEXT N_( \
     "This is the port used for UDP streams. By default, we chose 1234.")
 
+#define MTU_TEXT N_("MTU of the interface")
+#define MTU_LONGTEXT N_( \
+    "This is the typical size of UDP packets that we expect. On Ethernet " \
+    "it is usually 1500.")
+
 #define NETCHANNEL_TEXT N_("enable network channel mode")
 #define NETCHANNEL_LONGTEXT N_( \
     "Activate this option if you want to use the VideoLAN Channel Server.")
@@ -391,6 +396,7 @@ ADD_INTEGER ( "server-port", 1234, NULL, SERVER_PORT_TEXT, SERVER_PORT_LONGTEXT
 ADD_BOOL    ( "network-channel", 0, NULL, NETCHANNEL_TEXT, NETCHANNEL_LONGTEXT )
 ADD_STRING  ( "channel-server", "localhost", NULL, CHAN_SERV_TEXT, CHAN_SERV_LONGTEXT )
 ADD_INTEGER ( "channel-port", 6010, NULL, CHAN_PORT_TEXT, CHAN_PORT_LONGTEXT )
+ADD_INTEGER ( "mtu", 1500, NULL, MTU_TEXT, MTU_LONGTEXT )
 ADD_STRING  ( "iface", "eth0", NULL, IFACE_TEXT, IFACE_LONGTEXT )
 
 ADD_INTEGER ( "program", 0, NULL, INPUT_PROGRAM_TEXT, INPUT_PROGRAM_LONGTEXT )
