@@ -2,7 +2,7 @@
  * modules.c : Built-in and plugin modules management functions
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: modules.c,v 1.58 2002/04/11 08:55:49 sam Exp $
+ * $Id: modules.c,v 1.62 2002/05/22 19:31:33 gbazin Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Ethan C. Baldridge <BaldridgeE@cadmus.com>
@@ -35,9 +35,7 @@
 
 #include <videolan/vlc.h>
 
-#if !defined( _MSC_VER )
 #include <dirent.h>
-#endif
 
 #if defined(HAVE_DLFCN_H)                                /* Linux, BSD, Hurd */
 #   include <dlfcn.h>                        /* dlopen(), dlsym(), dlclose() */
@@ -45,7 +43,7 @@
 #elif defined(HAVE_IMAGE_H)                                          /* BeOS */
 #   include <image.h>
 #   define HAVE_DYNAMIC_PLUGINS
-#elif defined(WIN32) && defined( __MINGW32__ )
+#elif defined(WIN32)
 #   define HAVE_DYNAMIC_PLUGINS
 #else
 #   undef HAVE_DYNAMIC_PLUGINS
@@ -312,24 +310,29 @@ module_t * module_Need( int i_capability, char *psz_name, void *p_data )
             continue;
         }
 
-        /* Test if this plugin exports the required shortcut */
+        /* If we required a shortcut, check this plugin provides it. */
         if( psz_name != NULL && *psz_name )
         {
-            boolean_t b_ok = 0;
+            boolean_t b_trash = 1;
             int i_dummy;
 
             for( i_dummy = 0;
-                 !b_ok && p_module->pp_shortcuts[i_dummy];
+                 b_trash && p_module->pp_shortcuts[i_dummy];
                  i_dummy++ )
             {
-                b_ok = !strcmp( psz_name, p_module->pp_shortcuts[i_dummy] );
+                b_trash = strcmp( psz_name, p_module->pp_shortcuts[i_dummy] );
             }
 
-            if( !b_ok )
+            if( b_trash )
             {
                 continue;
             }
         }
+        /* If we didn't require a shortcut, trash zero-scored plugins */
+        else if( !p_module->pi_score[i_capability] )
+        {
+            continue;
+        }
 
         /* Special case: test if we requested a particular intf plugin */
         if( i_capability == MODULE_CAPABILITY_INTF )
