@@ -2,12 +2,12 @@
  * netutils.c: various network functions
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: netutils.c,v 1.63 2002/05/15 11:06:17 marcari Exp $
+ * $Id: netutils.c,v 1.66.2.2 2002/06/03 00:28:08 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Benoit Steiner <benny@via.ecp.fr>
  *          Henri Fallon <henri@videolan.org>
- *          Xavier Marchesini <xav@via.ecp.fr>
+ *          Xavier Marchesini <xav@alarue.net>
  *          Christophe Massiot <massiot@via.ecp.fr>
  *          Samuel Hocevar <sam@via.ecp.fr>
  *
@@ -76,6 +76,9 @@
 
 #include "netutils.h"
 
+#include "stream_control.h"
+#include "input_ext-intf.h"
+
 #include "intf_playlist.h"
 #include "network.h"
 
@@ -157,21 +160,31 @@ int network_ChannelJoin( int i_channel )
     struct timeval delay;
     fd_set fds;
 
-    if( !config_GetIntVariable( "network-channel" ) )
+    if( p_main->p_channel->i_channel == i_channel )
     {
-        intf_ErrMsg( "network: channels disabled, to enable them, use the"
-                     "--channels option" );
-        return -1;
+        return 0;
     }
 
-    /* If last change is too recent, wait a while */
-    if( mdate() - p_main->p_channel->last_change < INPUT_CHANNEL_CHANGE_DELAY )
+    /* FIXME: ugly hack to close input and outputs */
+    if( p_input_bank->pp_input[0] != NULL )
     {
-        intf_WarnMsg( 2, "network: waiting before changing channel" );
-        /* XXX Isn't this completely brain-damaged ??? -- Sam */
-        /* Yes it is. I don't think this is still justified with the new
-         * vlanserver --Meuuh */
-        mwait( p_main->p_channel->last_change + INPUT_CHANNEL_CHANGE_DELAY );
+        /* end playing item */
+        p_input_bank->pp_input[0]->b_eof = 1;
+
+        /* update playlist */
+        vlc_mutex_lock( &p_main->p_playlist->change_lock );
+
+        p_main->p_playlist->i_index--;
+        p_main->p_playlist->b_stopped = 1;
+
+        vlc_mutex_unlock( &p_main->p_playlist->change_lock );
+    }
+
+    if( !config_GetIntVariable( "network-channel" ) )
+    {
+        intf_ErrMsg( "network: channels disabled, to enable them, use the "
+                     "--channels option" );
+        return -1;
     }
 
     if( config_GetIntVariable( "ipv4" ) )
@@ -192,8 +205,7 @@ int network_ChannelJoin( int i_channel )
 
     i_port = config_GetIntVariable( "channel-port" );
 
-    intf_WarnMsg( 5, "channel: connecting to %s:%d",
-                     psz_vlcs, i_port );
+    intf_WarnMsg( 5, "channel: connecting to %s:%d", psz_vlcs, i_port );
 
     /* Prepare the network_socket_t structure */
     socket_desc.i_type = NETWORK_UDP;
@@ -262,21 +274,23 @@ int network_ChannelJoin( int i_channel )
     recv( i_fd, psz_mess, MESSAGE_LENGTH, 0 );
     psz_mess[ MESSAGE_LENGTH - 1 ] = '\0';
 
-    if( !strncasecmp( psz_mess, "E: ", 3 ) )
+    if( !strncasecmp( psz_mess, "E:", 2 ) )
     {
-        intf_ErrMsg( "network error: vlcs said '%s'", psz_mess + 3 );
+        intf_ErrMsg( "network error: vlcs said '%s'", psz_mess + 2 );
         close( i_fd );
         return -1;
     }
-    else if( !strncasecmp( psz_mess, "I: ", 3 ) )
+    else if( !strncasecmp( psz_mess, "I:", 2 ) )
     {
-        intf_WarnMsg( 2, "network info: vlcs said '%s'", psz_mess + 3 );
+        intf_WarnMsg( 2, "network info: vlcs said '%s'", psz_mess + 2 );
     }
     else /* We got something to play ! FIXME: not very nice */
     {
 #   define p_item \
         (&p_main->p_playlist->p_item[ p_main->p_playlist->i_index + 1])
         vlc_mutex_lock( &p_main->p_playlist->change_lock );
+        /* FIXME 2 */
+        p_main->p_playlist->b_stopped = 0;
         if( p_item )
         {
             free( p_item->psz_name );
