@@ -2,7 +2,7 @@
  * video_text.c : text manipulation functions
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: video_text.c,v 1.31 2001/11/28 15:08:06 massiot Exp $
+ * $Id: video_text.c,v 1.34 2002/02/19 00:50:20 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -25,38 +25,26 @@
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <errno.h>                                                  /* errno */
 #include <stdlib.h>                                                /* free() */
 #include <stdio.h>                                              /* sprintf() */
 #include <string.h>                                            /* strerror() */
 #include <fcntl.h>                                                 /* open() */
 
+#include <videolan/vlc.h>
+
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>                                    /* read(), close() */
 #elif defined( _MSC_VER ) && defined( _WIN32 )
 #   include <io.h>
 #endif
 
-#ifdef SYS_BEOS
-#   include "beos_specific.h"
-#endif
-
-#ifdef SYS_DARWIN
-#   include "darwin_specific.h"
-#endif
-
 #if defined( WIN32 )
 #   include <io.h>
 #endif
 
-#include "config.h"
-#include "common.h"
 #include "video_text.h"
 
-#include "intf_msg.h"
-
 /*****************************************************************************
  * vout_font_t: bitmap font
  *****************************************************************************
@@ -274,7 +262,7 @@ vout_font_t *vout_LoadFont( const char *psz_name )
 
     if( i_file == -1 )
     {
-        intf_DbgMsg( "vout error: can't open file '%s' (%s)",
+        intf_ErrMsg( "vout error: can't open file '%s' (%s)",
                      psz_name, strerror(errno) );
         return( NULL );
     }
@@ -372,9 +360,9 @@ vout_font_t *vout_LoadFont( const char *psz_name )
         break;
     }
 
-
-    intf_DbgMsg( "loaded %s: type %d, %d-%dx%d", psz_name, p_font->i_type,
+    intf_ErrMsg( "loaded %s: type %d, %d-%dx%d", psz_name, p_font->i_type,
                  p_font->i_width, p_font->i_interspacing, p_font->i_height );
+
     return( p_font );
 }
 
@@ -391,7 +379,6 @@ void vout_UnloadFont( vout_font_t *p_font )
         return;
     }
 
-    intf_DbgMsg( "vout: unloading font %p", p_font );
     free( p_font->p_data );
     free( p_font );
 }
